feat(1.90): update patches

This commit is contained in:
Baptiste Augrain 2024-05-06 00:44:51 +02:00
parent 0d28b4dfb7
commit c49b943405
5 changed files with 72 additions and 64 deletions

View file

@ -1,4 +1,4 @@
{
"tag": "1.88.0",
"commit": "d994aede3529f4d1af9eeaeb234d32fd936243e7"
"tag": "1.90.0",
"commit": "816c6f7d7bc4da9796cd19ac6b122b6e26f50d7f"
}

View file

@ -516,7 +516,7 @@ index fa001b5..13abac2 100644
+ throw Error(`Failed to download and unzip VSCodium ${quality} - ${commit}`);
}
diff --git a/src/vs/code/electron-main/app.ts b/src/vs/code/electron-main/app.ts
index 4417e6b..e43e115 100644
index f0f6dc5..751421d 100644
--- a/src/vs/code/electron-main/app.ts
+++ b/src/vs/code/electron-main/app.ts
@@ -571,3 +571,3 @@ export class CodeApplication extends Disposable {
@ -524,15 +524,6 @@ index 4417e6b..e43e115 100644
- this.logService.debug('Starting VS Code');
+ this.logService.debug('Starting VSCodium');
this.logService.debug(`from: ${this.environmentMainService.appRoot}`);
diff --git a/src/vs/code/electron-sandbox/issue/issueReporterService.ts b/src/vs/code/electron-sandbox/issue/issueReporterService.ts
index bfb1d01..a48311d 100644
--- a/src/vs/code/electron-sandbox/issue/issueReporterService.ts
+++ b/src/vs/code/electron-sandbox/issue/issueReporterService.ts
@@ -810,3 +810,3 @@ export class IssueReporter extends Disposable {
hide(descriptionTextArea);
- reset(descriptionTitle, localize('handlesIssuesElsewhere', "This extension handles issues outside of VS Code"));
+ reset(descriptionTitle, localize('handlesIssuesElsewhere', "This extension handles issues outside of VSCodium"));
reset(descriptionSubtitle, localize('elsewhereDescription', "The '{0}' extension prefers to use an external issue reporter. To be taken to that issue reporting experience, click the button below.", selectedExtension.displayName));
diff --git a/src/vs/editor/contrib/toggleTabFocusMode/browser/toggleTabFocusMode.ts b/src/vs/editor/contrib/toggleTabFocusMode/browser/toggleTabFocusMode.ts
index 7578cd6..3a8504b 100644
--- a/src/vs/editor/contrib/toggleTabFocusMode/browser/toggleTabFocusMode.ts
@ -637,7 +628,7 @@ index 2eed66f..4b30c61 100644
+ console.error('Unable to connect to VSCodium server: ' + message);
console.error(err);
diff --git a/src/vs/workbench/api/browser/viewsExtensionPoint.ts b/src/vs/workbench/api/browser/viewsExtensionPoint.ts
index 77ef2f7..b20340c 100644
index bab9d8b..0c65c32 100644
--- a/src/vs/workbench/api/browser/viewsExtensionPoint.ts
+++ b/src/vs/workbench/api/browser/viewsExtensionPoint.ts
@@ -51,3 +51,3 @@ const viewsContainerSchema: IJSONSchema = {
@ -720,52 +711,52 @@ index b38717d..dc91d34 100644
+ const message = requireReload ? localize('InstallVSIXAction.successReload', "Completed installing {0} extension from VSIX. Please reload VSCodium to enable it.", extension.displayName || extension.name)
: localize('InstallVSIXAction.success', "Completed installing {0} extension from VSIX.", extension.displayName || extension.name);
diff --git a/src/vs/workbench/contrib/extensions/browser/extensionsActions.ts b/src/vs/workbench/contrib/extensions/browser/extensionsActions.ts
index f514487..84574e2 100644
index 1fd2e61..1a2922a 100644
--- a/src/vs/workbench/contrib/extensions/browser/extensionsActions.ts
+++ b/src/vs/workbench/contrib/extensions/browser/extensionsActions.ts
@@ -106,3 +106,3 @@ export class PromptExtensionInstallFailureAction extends Action {
@@ -105,3 +105,3 @@ export class PromptExtensionInstallFailureAction extends Action {
if (this.error.name === ExtensionManagementErrorCode.Unsupported) {
- const productName = isWeb ? localize('VS Code for Web', "{0} for the Web", this.productService.nameLong) : this.productService.nameLong;
+ const productName = isWeb ? localize('VSCodium for Web', "{0} for the Web", this.productService.nameLong) : this.productService.nameLong;
const message = localize('cannot be installed', "The '{0}' extension is not available in {1}. Click 'More Information' to learn more.", this.extension.displayName || this.extension.identifier.id, productName);
@@ -387,3 +387,3 @@ export class InstallAction extends ExtensionAction {
@@ -386,3 +386,3 @@ export class InstallAction extends ExtensionAction {
} else if (this.extension.deprecationInfo.settings) {
- detail = localize('deprecated with alternate settings message', "This extension is deprecated as this functionality is now built-in to VS Code.");
+ detail = localize('deprecated with alternate settings message', "This extension is deprecated as this functionality is now built-in to VSCodium.");
@@ -775,3 +775,3 @@ export class UninstallAction extends ExtensionAction {
@@ -774,3 +774,3 @@ export class UninstallAction extends ExtensionAction {
await this.extensionsWorkbenchService.uninstall(this.extension);
- alert(localize('uninstallExtensionComplete', "Please reload Visual Studio Code to complete the uninstallation of the extension {0}.", this.extension.displayName));
+ alert(localize('uninstallExtensionComplete', "Please reload VSCodium to complete the uninstallation of the extension {0}.", this.extension.displayName));
} catch (error) {
@@ -2381,3 +2381,3 @@ export class ExtensionStatusAction extends ExtensionAction {
@@ -2380,3 +2380,3 @@ export class ExtensionStatusAction extends ExtensionAction {
const link = `[${localize('settings', "settings")}](${URI.parse(`command:workbench.action.openSettings?${encodeURIComponent(JSON.stringify([this.extension.deprecationInfo.settings.map(setting => `@id:${setting}`).join(' ')]))}`)})`;
- this.updateStatus({ icon: warningIcon, message: new MarkdownString(localize('deprecated with alternate settings tooltip', "This extension is deprecated as this functionality is now built-in to VS Code. Configure these {0} to use this functionality.", link)) }, true);
+ this.updateStatus({ icon: warningIcon, message: new MarkdownString(localize('deprecated with alternate settings tooltip', "This extension is deprecated as this functionality is now built-in to VSCodium. Configure these {0} to use this functionality.", link)) }, true);
} else {
@@ -2405,3 +2405,3 @@ export class ExtensionStatusAction extends ExtensionAction {
@@ -2404,3 +2404,3 @@ export class ExtensionStatusAction extends ExtensionAction {
if (this.extensionManagementServerService.webExtensionManagementServer) {
- const productName = localize('VS Code for Web', "{0} for the Web", this.productService.nameLong);
+ const productName = localize('VSCodium for Web', "{0} for the Web", this.productService.nameLong);
const message = new MarkdownString(`${localize('not web tooltip', "The '{0}' extension is not available in {1}.", this.extension.displayName || this.extension.identifier.id, productName)} [${localize('learn why', "Learn Why")}](https://aka.ms/vscode-web-extensions-guide)`);
@@ -2682,3 +2682,3 @@ export class ReinstallAction extends Action {
@@ -2681,3 +2681,3 @@ export class ReinstallAction extends Action {
const requireReload = !(extension.local && this.extensionService.canAddExtension(toExtensionDescription(extension.local)));
- const message = requireReload ? localize('ReinstallAction.successReload', "Please reload Visual Studio Code to complete reinstalling the extension {0}.", extension.identifier.id)
+ const message = requireReload ? localize('ReinstallAction.successReload', "Please reload VSCodium to complete reinstalling the extension {0}.", extension.identifier.id)
: localize('ReinstallAction.success', "Reinstalling the extension {0} is completed.", extension.identifier.id);
diff --git a/src/vs/workbench/contrib/extensions/common/extensionsFileTemplate.ts b/src/vs/workbench/contrib/extensions/common/extensionsFileTemplate.ts
index 3e8cd71..6142f61 100644
@ -846,7 +837,7 @@ index b24d91f..a098a62 100644
+ const message = await this.tasExperimentService?.getTreatment<string>('CESSurveyMessage') ?? nls.localize('cesSurveyQuestion', 'Got a moment to help the VSCodium team? Please tell us about your experience with VSCodium so far.');
const button = await this.tasExperimentService?.getTreatment<string>('CESSurveyButton') ?? nls.localize('giveFeedback', "Give Feedback");
diff --git a/src/vs/workbench/contrib/tasks/browser/abstractTaskService.ts b/src/vs/workbench/contrib/tasks/browser/abstractTaskService.ts
index cd47379..9395987 100644
index 1a02a11..925148a 100644
--- a/src/vs/workbench/contrib/tasks/browser/abstractTaskService.ts
+++ b/src/vs/workbench/contrib/tasks/browser/abstractTaskService.ts
@@ -3174,3 +3174,3 @@ export abstract class AbstractTaskService extends Disposable implements ITaskSer
@ -869,7 +860,7 @@ index 9cae427..bfb5063 100644
+ description: nls.localize('JsonSchema.promptOnClose', 'Whether the user is prompted when VSCodium closes with a running background task.'),
default: false
diff --git a/src/vs/workbench/contrib/tasks/common/jsonSchema_v2.ts b/src/vs/workbench/contrib/tasks/common/jsonSchema_v2.ts
index 4d90798..38bd65b 100644
index 658cb5f..70eac33 100644
--- a/src/vs/workbench/contrib/tasks/common/jsonSchema_v2.ts
+++ b/src/vs/workbench/contrib/tasks/common/jsonSchema_v2.ts
@@ -411,3 +411,3 @@ const taskConfiguration: IJSONSchema = {
@ -887,7 +878,7 @@ index 9efbc2a..18c7aec 100644
+ message: nls.localize('TaskSystem.noProcess', 'The launched task doesn\'t exist anymore. If the task spawned background processes exiting VSCodium might result in orphaned processes. To avoid this start the last background process with a wait flag.'),
primaryButton: nls.localize({ key: 'TaskSystem.exitAnyways', comment: ['&& denotes a mnemonic'] }, "&&Exit Anyways"),
diff --git a/src/vs/workbench/contrib/terminal/browser/terminalView.ts b/src/vs/workbench/contrib/terminal/browser/terminalView.ts
index ea49f68..10acc6a 100644
index 966c4ea..fe0fc91 100644
--- a/src/vs/workbench/contrib/terminal/browser/terminalView.ts
+++ b/src/vs/workbench/contrib/terminal/browser/terminalView.ts
@@ -201,3 +201,3 @@ export class TerminalViewPane extends ViewPane {
@ -896,50 +887,50 @@ index ea49f68..10acc6a 100644
+ this._notificationService.prompt(Severity.Warning, nls.localize('terminal.monospaceOnly', "The terminal only supports monospace fonts. Be sure to restart VSCodium if this is a newly installed font."), choices);
}
diff --git a/src/vs/workbench/contrib/terminal/common/terminalConfiguration.ts b/src/vs/workbench/contrib/terminal/common/terminalConfiguration.ts
index cb9ab6e..01af4ea 100644
index 9f87d58..e123813 100644
--- a/src/vs/workbench/contrib/terminal/common/terminalConfiguration.ts
+++ b/src/vs/workbench/contrib/terminal/common/terminalConfiguration.ts
@@ -286,3 +286,3 @@ const terminalConfiguration: IConfigurationNode = {
@@ -293,3 +293,3 @@ const terminalConfiguration: IConfigurationNode = {
[TerminalSettingId.DetectLocale]: {
- markdownDescription: localize('terminal.integrated.detectLocale', "Controls whether to detect and set the `$LANG` environment variable to a UTF-8 compliant option since VS Code's terminal only supports UTF-8 encoded data coming from the shell."),
+ markdownDescription: localize('terminal.integrated.detectLocale', "Controls whether to detect and set the `$LANG` environment variable to a UTF-8 compliant option since VSCodium's terminal only supports UTF-8 encoded data coming from the shell."),
type: 'string',
@@ -300,3 +300,3 @@ const terminalConfiguration: IConfigurationNode = {
@@ -307,3 +307,3 @@ const terminalConfiguration: IConfigurationNode = {
markdownEnumDescriptions: [
- localize('terminal.integrated.gpuAcceleration.auto', "Let VS Code detect which renderer will give the best experience."),
+ localize('terminal.integrated.gpuAcceleration.auto', "Let VSCodium detect which renderer will give the best experience."),
localize('terminal.integrated.gpuAcceleration.on', "Enable GPU acceleration within the terminal."),
@@ -389,3 +389,3 @@ const terminalConfiguration: IConfigurationNode = {
@@ -395,3 +395,3 @@ const terminalConfiguration: IConfigurationNode = {
'terminal.integrated.commandsToSkipShell',
- "A set of command IDs whose keybindings will not be sent to the shell but instead always be handled by VS Code. This allows keybindings that would normally be consumed by the shell to act instead the same as when the terminal is not focused, for example `Ctrl+P` to launch Quick Open.\n\n&nbsp;\n\nMany commands are skipped by default. To override a default and pass that command's keybinding to the shell instead, add the command prefixed with the `-` character. For example add `-workbench.action.quickOpen` to allow `Ctrl+P` to reach the shell.\n\n&nbsp;\n\nThe following list of default skipped commands is truncated when viewed in Settings Editor. To see the full list, {1} and search for the first command from the list below.\n\n&nbsp;\n\nDefault Skipped Commands:\n\n{0}",
+ "A set of command IDs whose keybindings will not be sent to the shell but instead always be handled by VSCodium. This allows keybindings that would normally be consumed by the shell to act instead the same as when the terminal is not focused, for example `Ctrl+P` to launch Quick Open.\n\n&nbsp;\n\nMany commands are skipped by default. To override a default and pass that command's keybinding to the shell instead, add the command prefixed with the `-` character. For example add `-workbench.action.quickOpen` to allow `Ctrl+P` to reach the shell.\n\n&nbsp;\n\nThe following list of default skipped commands is truncated when viewed in Settings Editor. To see the full list, {1} and search for the first command from the list below.\n\n&nbsp;\n\nDefault Skipped Commands:\n\n{0}",
DEFAULT_COMMANDS_TO_SKIP_SHELL.sort().map(command => `- ${command}`).join('\n'),
@@ -401,3 +401,3 @@ const terminalConfiguration: IConfigurationNode = {
@@ -407,3 +407,3 @@ const terminalConfiguration: IConfigurationNode = {
[TerminalSettingId.AllowChords]: {
- markdownDescription: localize('terminal.integrated.allowChords', "Whether or not to allow chord keybindings in the terminal. Note that when this is true and the keystroke results in a chord it will bypass {0}, setting this to false is particularly useful when you want ctrl+k to go to your shell (not VS Code).", '`#terminal.integrated.commandsToSkipShell#`'),
+ markdownDescription: localize('terminal.integrated.allowChords', "Whether or not to allow chord keybindings in the terminal. Note that when this is true and the keystroke results in a chord it will bypass {0}, setting this to false is particularly useful when you want ctrl+k to go to your shell (not VSCodium).", '`#terminal.integrated.commandsToSkipShell#`'),
type: 'boolean',
@@ -412,3 +412,3 @@ const terminalConfiguration: IConfigurationNode = {
@@ -418,3 +418,3 @@ const terminalConfiguration: IConfigurationNode = {
restricted: true,
- markdownDescription: localize('terminal.integrated.env.osx', "Object with environment variables that will be added to the VS Code process to be used by the terminal on macOS. Set to `null` to delete the environment variable."),
+ markdownDescription: localize('terminal.integrated.env.osx', "Object with environment variables that will be added to the VSCodium process to be used by the terminal on macOS. Set to `null` to delete the environment variable."),
type: 'object',
@@ -421,3 +421,3 @@ const terminalConfiguration: IConfigurationNode = {
@@ -427,3 +427,3 @@ const terminalConfiguration: IConfigurationNode = {
restricted: true,
- markdownDescription: localize('terminal.integrated.env.linux', "Object with environment variables that will be added to the VS Code process to be used by the terminal on Linux. Set to `null` to delete the environment variable."),
+ markdownDescription: localize('terminal.integrated.env.linux', "Object with environment variables that will be added to the VSCodium process to be used by the terminal on Linux. Set to `null` to delete the environment variable."),
type: 'object',
@@ -430,3 +430,3 @@ const terminalConfiguration: IConfigurationNode = {
@@ -436,3 +436,3 @@ const terminalConfiguration: IConfigurationNode = {
restricted: true,
- markdownDescription: localize('terminal.integrated.env.windows', "Object with environment variables that will be added to the VS Code process to be used by the terminal on Windows. Set to `null` to delete the environment variable."),
+ markdownDescription: localize('terminal.integrated.env.windows', "Object with environment variables that will be added to the VSCodium process to be used by the terminal on Windows. Set to `null` to delete the environment variable."),
type: 'object',
@@ -593,3 +593,3 @@ const terminalConfiguration: IConfigurationNode = {
@@ -560,3 +560,3 @@ const terminalConfiguration: IConfigurationNode = {
[TerminalSettingId.AutoReplies]: {
- markdownDescription: localize('terminal.integrated.autoReplies', "A set of messages that, when encountered in the terminal, will be automatically responded to. Provided the message is specific enough, this can help automate away common responses.\n\nRemarks:\n\n- Use {0} to automatically respond to the terminate batch job prompt on Windows.\n- The message includes escape sequences so the reply might not happen with styled text.\n- Each reply can only happen once every second.\n- Use {1} in the reply to mean the enter key.\n- To unset a default key, set the value to null.\n- Restart VS Code if new don't apply.", '`"Terminate batch job (Y/N)": "Y\\r"`', '`"\\r"`'),
+ markdownDescription: localize('terminal.integrated.autoReplies', "A set of messages that, when encountered in the terminal, will be automatically responded to. Provided the message is specific enough, this can help automate away common responses.\n\nRemarks:\n\n- Use {0} to automatically respond to the terminate batch job prompt on Windows.\n- The message includes escape sequences so the reply might not happen with styled text.\n- Each reply can only happen once every second.\n- Use {1} in the reply to mean the enter key.\n- To unset a default key, set the value to null.\n- Restart VSCodium if new don't apply.", '`"Terminate batch job (Y/N)": "Y\\r"`', '`"\\r"`'),
type: 'object',
@@ -606,3 +606,3 @@ const terminalConfiguration: IConfigurationNode = {
@@ -573,3 +573,3 @@ const terminalConfiguration: IConfigurationNode = {
restricted: true,
- markdownDescription: localize('terminal.integrated.shellIntegration.enabled', "Determines whether or not shell integration is auto-injected to support features like enhanced command tracking and current working directory detection. \n\nShell integration works by injecting the shell with a startup script. The script gives VS Code insight into what is happening within the terminal.\n\nSupported shells:\n\n- Linux/macOS: bash, fish, pwsh, zsh\n - Windows: pwsh, git bash\n\nThis setting applies only when terminals are created, so you will need to restart your terminals for it to take effect.\n\n Note that the script injection may not work if you have custom arguments defined in the terminal profile, have enabled {1}, have a [complex bash `PROMPT_COMMAND`](https://code.visualstudio.com/docs/editor/integrated-terminal#_complex-bash-promptcommand), or other unsupported setup. To disable decorations, see {0}", '`#terminal.integrated.shellIntegrations.decorationsEnabled#`', '`#editor.accessibilitySupport#`'),
+ markdownDescription: localize('terminal.integrated.shellIntegration.enabled', "Determines whether or not shell integration is auto-injected to support features like enhanced command tracking and current working directory detection. \n\nShell integration works by injecting the shell with a startup script. The script gives VSCodium insight into what is happening within the terminal.\n\nSupported shells:\n\n- Linux/macOS: bash, fish, pwsh, zsh\n - Windows: pwsh, git bash\n\nThis setting applies only when terminals are created, so you will need to restart your terminals for it to take effect.\n\n Note that the script injection may not work if you have custom arguments defined in the terminal profile, have enabled {1}, have a [complex bash `PROMPT_COMMAND`](https://code.visualstudio.com/docs/editor/integrated-terminal#_complex-bash-promptcommand), or other unsupported setup. To disable decorations, see {0}", '`#terminal.integrated.shellIntegrations.decorationsEnabled#`', '`#editor.accessibilitySupport#`'),
@ -989,10 +980,10 @@ index c5c2258..fb5045b 100644
+ content += `// By default, VSCodium trusts "localhost".\n`;
}
diff --git a/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.contribution.ts b/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.contribution.ts
index c957f53..77c3717 100644
index c581ac0..2be335c 100644
--- a/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.contribution.ts
+++ b/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.contribution.ts
@@ -324,3 +324,3 @@ configurationRegistry.registerConfiguration({
@@ -325,3 +325,3 @@ configurationRegistry.registerConfiguration({
localize({ comment: ['This is the description for a setting. Values surrounded by single quotes are not to be translated.'], key: 'workbench.startupEditor.none' }, "Start without an editor."),
- localize({ comment: ['This is the description for a setting. Values surrounded by single quotes are not to be translated.'], key: 'workbench.startupEditor.welcomePage' }, "Open the Welcome page, with content to aid in getting started with VS Code and extensions."),
+ localize({ comment: ['This is the description for a setting. Values surrounded by single quotes are not to be translated.'], key: 'workbench.startupEditor.welcomePage' }, "Open the Welcome page, with content to aid in getting started with VSCodium and extensions."),
@ -1128,16 +1119,16 @@ index ff0aeec..23d9fcb 100644
+ description: localize('argv.useInMemorySecretStorage', "Ensures that an in-memory store will be used for secret storage instead of using the OS's credential store. This is often used when running VSCodium extension tests or when you're experiencing difficulties with the credential store.")
}
diff --git a/src/vs/workbench/services/extensionManagement/common/extensionManagementService.ts b/src/vs/workbench/services/extensionManagement/common/extensionManagementService.ts
index 8e69418..f6b7355 100644
index 9b96150..84f097f 100644
--- a/src/vs/workbench/services/extensionManagement/common/extensionManagementService.ts
+++ b/src/vs/workbench/services/extensionManagement/common/extensionManagementService.ts
@@ -678,3 +678,3 @@ export class ExtensionManagementService extends Disposable implements IWorkbench
@@ -706,3 +706,3 @@ export class ExtensionManagementService extends Disposable implements IWorkbench
- const productName = localize('VS Code for Web', "{0} for the Web", this.productService.nameLong);
+ const productName = localize('VSCodium for Web', "{0} for the Web", this.productService.nameLong);
const virtualWorkspaceSupport = this.extensionManifestPropertiesService.getExtensionVirtualWorkspaceSupportType(manifest);
diff --git a/src/vs/workbench/services/extensions/browser/extensionUrlHandler.ts b/src/vs/workbench/services/extensions/browser/extensionUrlHandler.ts
index 65672a1..062933d 100644
index 696f822..f548e73 100644
--- a/src/vs/workbench/services/extensions/browser/extensionUrlHandler.ts
+++ b/src/vs/workbench/services/extensions/browser/extensionUrlHandler.ts
@@ -86,3 +86,3 @@ type ExtensionUrlHandlerClassification = {

View file

@ -29,19 +29,19 @@ index 4e7208c..f7304bc 100644
+target "16.20.2"
ms_build_id "256117"
diff --git a/remote/package.json b/remote/package.json
index 974450e..513856f 100644
index c0397ce..e398804 100644
--- a/remote/package.json
+++ b/remote/package.json
@@ -31,3 +31,3 @@
@@ -30,3 +30,3 @@
"native-watchdog": "^1.4.1",
- "node-pty": "1.1.0-beta11",
+ "node-pty": "1.1.0-beta4",
"tas-client-umd": "0.1.8",
"tas-client-umd": "0.2.0",
diff --git a/remote/yarn.lock b/remote/yarn.lock
index d62eb4b..f175b85 100644
index 88d688b..313d3f6 100644
--- a/remote/yarn.lock
+++ b/remote/yarn.lock
@@ -391,2 +391,7 @@ ms@2.1.2:
@@ -386,2 +386,7 @@ ms@2.1.2:
+nan@^2.17.0:
+ version "2.18.0"
@ -49,12 +49,12 @@ index d62eb4b..f175b85 100644
+ integrity sha512-W7tfG7vMOGtD30sHoZSSc/JVYiyDPEyQVso/Zz+/uQd0B0L46gtC+pHha5FFMRpil6fm/AoEcRWyOVi4+E/f8w==
+
napi-build-utils@^1.0.1:
@@ -408,3 +413,3 @@ node-abi@^3.3.0:
@@ -403,3 +408,3 @@ node-abi@^3.3.0:
-node-addon-api@7.1.0, node-addon-api@^7.1.0:
+node-addon-api@7.1.0:
version "7.1.0"
@@ -433,8 +438,8 @@ node-gyp-build@^4.3.0:
@@ -428,8 +433,8 @@ node-gyp-build@^4.3.0:
-node-pty@1.1.0-beta11:
- version "1.1.0-beta11"

View file

@ -1,14 +1,14 @@
diff --git a/src/vs/code/electron-sandbox/issue/issueReporterModel.ts b/src/vs/code/electron-sandbox/issue/issueReporterModel.ts
index 74f9939..341ef06 100644
index 1541f98..ea3af1b 100644
--- a/src/vs/code/electron-sandbox/issue/issueReporterModel.ts
+++ b/src/vs/code/electron-sandbox/issue/issueReporterModel.ts
@@ -79,3 +79,3 @@ ${this._data.issueDescription}
@@ -80,3 +80,3 @@ ${this._data.issueDescription}
${this.getExtensionVersion()}
-VS Code version: ${this._data.versionInfo && this._data.versionInfo.vscodeVersion}
+VSCodium version: ${this._data.versionInfo && this._data.versionInfo.vscodeVersion}
OS version: ${this._data.versionInfo && this._data.versionInfo.os}
diff --git a/src/vs/code/electron-sandbox/issue/issueReporterPage.ts b/src/vs/code/electron-sandbox/issue/issueReporterPage.ts
index 96ec5f7..5c091d9 100644
index 7cf3337..cd9eb84 100644
--- a/src/vs/code/electron-sandbox/issue/issueReporterPage.ts
+++ b/src/vs/code/electron-sandbox/issue/issueReporterPage.ts
@@ -18,3 +18,3 @@ const reviewGuidanceLabel = localize( // intentionally not escaped because of it
@ -22,10 +22,10 @@ index 96ec5f7..5c091d9 100644
+ 'Before you report an issue here please <a href="https://github.com/VSCodium/vscodium/wiki/Submitting-Bugs-and-Suggestions" target="_blank">review the guidance we provide</a>.'
);
diff --git a/src/vs/code/electron-sandbox/issue/issueReporterService.ts b/src/vs/code/electron-sandbox/issue/issueReporterService.ts
index d7f98f6..ed54042 100644
index 6edb382..914f15a 100644
--- a/src/vs/code/electron-sandbox/issue/issueReporterService.ts
+++ b/src/vs/code/electron-sandbox/issue/issueReporterService.ts
@@ -517,5 +517,5 @@ export class IssueReporter extends Disposable {
@@ -552,5 +552,5 @@ export class IssueReporter extends Disposable {
- private searchVSCodeIssues(title: string, issueDescription?: string): void {
+ private searchVSCodeIssues(title: string, _issueDescription?: string): void {
@ -33,7 +33,7 @@ index d7f98f6..ed54042 100644
- this.searchDuplicates(title, issueDescription);
+ this.searchGitHub('VSCodium/vscodium', title);
} else {
@@ -611,33 +611,2 @@ export class IssueReporter extends Disposable {
@@ -646,33 +646,2 @@ export class IssueReporter extends Disposable {
- @debounce(300)
- private searchDuplicates(title: string, body?: string): void {
@ -67,11 +67,18 @@ index d7f98f6..ed54042 100644
- }
-
private displaySearchResults(results: SearchResult[]) {
@@ -729,3 +698,3 @@ export class IssueReporter extends Disposable {
@@ -768,4 +737,4 @@ export class IssueReporter extends Disposable {
sourceSelect.append(this.makeOption('', localize('selectSource', "Select source"), true));
- sourceSelect.append(this.makeOption('vscode', localize('vscode', "Visual Studio Code"), false));
+ sourceSelect.append(this.makeOption('vscode', localize('vscode', "VSCodium"), false));
sourceSelect.append(this.makeOption('extension', localize('extension', "An extension"), false));
- sourceSelect.append(this.makeOption(IssueSource.VSCode, localize('vscode', "Visual Studio Code"), false));
- sourceSelect.append(this.makeOption(IssueSource.Extension, localize('extension', "A VS Code extension"), false));
+ sourceSelect.append(this.makeOption(IssueSource.VSCode, localize('vscodium', "VSCodium"), false));
+ sourceSelect.append(this.makeOption(IssueSource.Extension, localize('extension', "A VSCodium extension"), false));
if (this.configuration.product.reportMarketplaceIssueUrl) {
@@ -829,3 +798,3 @@ export class IssueReporter extends Disposable {
hide(descriptionTextArea);
- reset(descriptionTitle, localize('handlesIssuesElsewhere', "This extension handles issues outside of VS Code"));
+ reset(descriptionTitle, localize('handlesIssuesElsewhere', "This extension handles issues outside of VSCodium"));
reset(descriptionSubtitle, localize('elsewhereDescription', "The '{0}' extension prefers to use an external issue reporter. To be taken to that issue reporting experience, click the button below.", selectedExtension.displayName));
diff --git a/src/vs/workbench/contrib/extensions/browser/extensionsWorkbenchService.ts b/src/vs/workbench/contrib/extensions/browser/extensionsWorkbenchService.ts
index f3ef2fb..4301dcb 100644
index fb123e0..e04f413 100644
--- a/src/vs/workbench/contrib/extensions/browser/extensionsWorkbenchService.ts
+++ b/src/vs/workbench/contrib/extensions/browser/extensionsWorkbenchService.ts
@@ -405,3 +405,3 @@ export class Extension implements IExtension {
@@ -406,3 +406,3 @@ export class Extension implements IExtension {
return Promise.resolve(`# ${this.displayName || this.name}
**Notice:** This extension is bundled with Visual Studio Code. It can be disabled but not uninstalled.
## Features
@@ -443,3 +443,3 @@ ${this.description}
@@ -444,3 +444,3 @@ ${this.description}
if (this.type === ExtensionType.System) {
- return Promise.resolve('Please check the [VS Code Release Notes](command:update.showCurrentReleaseNotes) for changes to the built-in extensions.');
+ return Promise.resolve('Please check the [VSCodium Release Notes](command:update.showCurrentReleaseNotes) for changes to the built-in extensions.');
- return Promise.resolve(`Please check the [VS Code Release Notes](command:${ShowCurrentReleaseNotesActionId}) for changes to the built-in extensions.`);
+ return Promise.resolve(`Please check the [VSCodium Release Notes](command:${ShowCurrentReleaseNotesActionId}) for changes to the built-in extensions.`);
}
@@ -406,3 +406,3 @@ export class Extension implements IExtension {
return Promise.resolve(`# ${this.displayName || this.name}
-**Notice:** This extension is bundled with Visual Studio Code. It can be disabled but not uninstalled.
+**Notice:** This extension is bundled with VSCodium. It can be disabled but not uninstalled.
## Features
diff --git a/src/vs/workbench/contrib/extensions/electron-sandbox/extensionsSlowActions.ts b/src/vs/workbench/contrib/extensions/electron-sandbox/extensionsSlowActions.ts
index 87839a6..49727fc 100644
--- a/src/vs/workbench/contrib/extensions/electron-sandbox/extensionsSlowActions.ts

View file

@ -189,6 +189,7 @@
"contribCommentThreadAdditionalMenu",
"contribCommentsViewThreadMenus",
"contribEditorContentMenu",
"contribMultiDiffEditorMenus",
"contribShareMenu",
"diffCommand",
"fileComments",
@ -199,10 +200,14 @@
"treeViewMarkdownMessage"
],
"GitHub.copilot": [
"inlineCompletionsAdditions"
"inlineCompletionsAdditions",
"interactive",
"terminalDataWriteEvent"
],
"GitHub.copilot-nightly": [
"inlineCompletionsAdditions"
"inlineCompletionsAdditions",
"interactive",
"terminalDataWriteEvent"
],
"GitHub.copilot-chat": [
"interactive",
@ -210,11 +215,11 @@
"terminalExecuteCommandEvent",
"terminalSelection",
"terminalQuickFixProvider",
"chatProvider",
"chatParticipant",
"chatParticipantAdditions",
"defaultChatParticipant",
"chatVariableResolver",
"chatProvider",
"mappedEditsProvider",
"aiRelatedInformation",
"codeActionAI",
@ -225,7 +230,9 @@
"findFiles2",
"extensionsAny",
"authLearnMore",
"testObserver"
"testObserver",
"aiTextSearchProvider",
"documentFiltersExclusive"
],
"GitHub.remotehub": [
"contribRemoteHelp",
@ -242,6 +249,9 @@
"textSearchProvider",
"timeline"
],
"GitHub.copilot-nes": [
"inlineEdit"
],
"ms-python.gather": [
"notebookCellExecutionState"
],